# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.errors_api import ErrorsApi  # noqa: E501
from mux_python.rest import ApiException


class TestErrorsApi(unittest.TestCase):
    """ErrorsApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.errors_api.ErrorsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_list_errors(self):
        """Test case for list_errors

        List Errors  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
