# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.url_signing_keys_api import URLSigningKeysApi  # noqa: E501
from mux_python.rest import ApiException


class TestURLSigningKeysApi(unittest.TestCase):
    """URLSigningKeysApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.url_signing_keys_api.URLSigningKeysApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_url_signing_key(self):
        """Test case for create_url_signing_key

        Create a URL signing key  # noqa: E501
        """
        pass

    def test_delete_url_signing_key(self):
        """Test case for delete_url_signing_key

        Delete a URL signing key  # noqa: E501
        """
        pass

    def test_get_url_signing_key(self):
        """Test case for get_url_signing_key

        Retrieve a URL signing key  # noqa: E501
        """
        pass

    def test_list_url_signing_keys(self):
        """Test case for list_url_signing_keys

        List URL signing keys  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
