# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.metrics_api import MetricsApi  # noqa: E501
from mux_python.rest import ApiException


class TestMetricsApi(unittest.TestCase):
    """MetricsApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.metrics_api.MetricsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_metric_timeseries_data(self):
        """Test case for get_metric_timeseries_data

        Get metric timeseries data  # noqa: E501
        """
        pass

    def test_get_overall_values(self):
        """Test case for get_overall_values

        Get Overall values  # noqa: E501
        """
        pass

    def test_list_all_metric_values(self):
        """Test case for list_all_metric_values

        List all metric values  # noqa: E501
        """
        pass

    def test_list_breakdown_values(self):
        """Test case for list_breakdown_values

        List breakdown values  # noqa: E501
        """
        pass

    def test_list_insights(self):
        """Test case for list_insights

        List Insights  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
