# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.direct_uploads_api import DirectUploadsApi  # noqa: E501
from mux_python.rest import ApiException


class TestDirectUploadsApi(unittest.TestCase):
    """DirectUploadsApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.direct_uploads_api.DirectUploadsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_direct_upload(self):
        """Test case for cancel_direct_upload

        Cancel a direct upload  # noqa: E501
        """
        pass

    def test_create_direct_upload(self):
        """Test case for create_direct_upload

        Create a new direct upload URL  # noqa: E501
        """
        pass

    def test_get_direct_upload(self):
        """Test case for get_direct_upload

        Retrieve a single direct upload's info  # noqa: E501
        """
        pass

    def test_list_direct_uploads(self):
        """Test case for list_direct_uploads

        List direct uploads  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
