# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.assets_api import AssetsApi  # noqa: E501
from mux_python.rest import ApiException


class TestAssetsApi(unittest.TestCase):
    """AssetsApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.assets_api.AssetsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_asset(self):
        """Test case for create_asset

        Create an asset  # noqa: E501
        """
        pass

    def test_create_asset_playback_id(self):
        """Test case for create_asset_playback_id

        Create a playback ID  # noqa: E501
        """
        pass

    def test_create_asset_track(self):
        """Test case for create_asset_track

        Create an asset track  # noqa: E501
        """
        pass

    def test_delete_asset(self):
        """Test case for delete_asset

        Delete an asset  # noqa: E501
        """
        pass

    def test_delete_asset_playback_id(self):
        """Test case for delete_asset_playback_id

        Delete a playback ID  # noqa: E501
        """
        pass

    def test_delete_asset_track(self):
        """Test case for delete_asset_track

        Delete an asset track  # noqa: E501
        """
        pass

    def test_get_asset(self):
        """Test case for get_asset

        Retrieve an asset  # noqa: E501
        """
        pass

    def test_get_asset_input_info(self):
        """Test case for get_asset_input_info

        Retrieve asset input info  # noqa: E501
        """
        pass

    def test_get_asset_playback_id(self):
        """Test case for get_asset_playback_id

        Retrieve a playback ID  # noqa: E501
        """
        pass

    def test_list_assets(self):
        """Test case for list_assets

        List assets  # noqa: E501
        """
        pass

    def test_update_asset_master_access(self):
        """Test case for update_asset_master_access

        Update master access  # noqa: E501
        """
        pass

    def test_update_asset_mp4_support(self):
        """Test case for update_asset_mp4_support

        Update MP4 support  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
