# coding: utf-8

"""
Mux Python - Copyright 2019 Mux Inc.

NOTE: This class is auto generated. Do not edit the class manually.
"""


from __future__ import absolute_import

import unittest

import mux_python
from mux_python.api.filters_api import FiltersApi  # noqa: E501
from mux_python.rest import ApiException


class TestFiltersApi(unittest.TestCase):
    """FiltersApi unit test stubs"""

    def setUp(self):
        self.api = mux_python.api.filters_api.FiltersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_list_filter_values(self):
        """Test case for list_filter_values

        Lists values for a specific filter  # noqa: E501
        """
        pass

    def test_list_filters(self):
        """Test case for list_filters

        List Filters  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
